@@ -76,7 +76,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define  SELprintf  printf  
 #define  SMS_SA   0x41
 #define  SMI_SA   0x21
-static char *progver   = "3.01";
+static char *progver   = "3.07";
 static char *progname  = "ievents";
 static char fsensdesc = 0;   /* 1= get extended sensor descriptions*/
 static char fcanonical = 0;  /* 1= show canonical, delimited output*/
@@ -290,7 +290,7 @@ char * boot_init_str[NBOOTI] = {  /* System Boot Initiated */
  /*06*/ "SW Warm Reset",  
  /*07*/ "RestartCause" };
 
-#define NOSBOOT  8
+#define NOSBOOT  10
 char * osboot_str[NOSBOOT] = {  /* OS Boot */
  /*00*/ "A: boot completed",  
  /*01*/ "C: boot completed",  
@@ -298,7 +298,9 @@ char * osboot_str[NOSBOOT] = {  /* OS Boot */
  /*03*/ "Diag boot completed",  
  /*04*/ "CDROM boot completed",  
  /*05*/ "ROM boot completed",  
- /*06*/ "Other boot completed" };
+ /*06*/ "Other boot completed",
+ /*07*/ "USB7 boot completed",
+ /*08*/ "USB8 boot completed" };
 
 #define NSLOTC  9
 char * slot_str[NSLOTC] = {  /* Slot/Connector descriptions */
@@ -397,7 +399,7 @@ char * avail_str[N_AVAIL] = {  /* Discrete Availability, evtype 0x0A */
  /*08*/ "Install Error"};
 
 
-#define NSDESC   87  
+#define NSDESC   88  
 struct {
  ushort genid;  /* generator id: BIOS, BMC, etc. (slave_addr/channel) */
  uchar s_typ;   /* 1=temp,2=voltage,4=fan,... */
@@ -457,9 +459,10 @@ struct {
 {HSC_SA,0x0d, 0xff, 0x08, 0x01,0xff,0xff, 0,"Device Inserted"},   /*HSC*/
 {0xffff,0x0d, 0xff, 0x6f, 0x00,0xff,0xff, 0,"Drive present"},   /*Romley BMC*/
 {0xffff,0x0d, 0xff, 0xef, 0x00,0xff,0xff, 0,"Drive removed"},   /*BMC*/
-{0xffff,0x0d, 0xff, 0x6f, 0x01,0xff,0xff, 2,"Drive fault"},  
+{0xffff,0x0d, 0xff, 0x6f, 0x01,0xff,0xff, 2,"Drive fault"},    /*0x0D Drive*/
 {0xffff,0x0d, 0xff, 0xef, 0x01,0xff,0xff, 0,"Drive fault OK"},  
 {0xffff,0x0d, 0xff, 0x6f, 0x02,0xff,0xff, 1,"Drive predict fail"},
+{0xffff,0x0d, 0xff, 0x6f, 0x05,0xff,0xff, 1,"Drive not redundant"},
 {0xffff,0x0d, 0xff, 0x6f, 0x07,0xff,0xff, 0,"Rebuild in progress"},
 {0xffff,0x0d, 0xff, 0xef, 0x07,0xff,0xff, 0,"Rebuild complete"},   
 {0xffff,0x14, 0xff, 0xff, 0x42,0xff,0xff, 1,"Reset Button pressed"},
@@ -1594,20 +1597,21 @@ int decode_sel_entry( uchar *pevt, char *outbuf, int szbuf)
 	char fhave_sdr = 0;
 	char mdesc[80];   /*used for oem memory description*/
 	int msz;
+	char *mfgstr;
+	int mfg;
 
 	if (outbuf == NULL) return(ERR_BAD_PARAM);
 	if (pevt == NULL) {
 		outbuf[0] = 0;
 		return(ERR_BAD_PARAM);
 	}
-        get_mfgid(&vend,&prod); /*saved from ipmi_getdeviceid */
+	get_mfgid(&vend,&prod); /*saved from ipmi_getdeviceid */
 	psel = (SEL_RECORD *)pevt;
 
 	j = decode_sel_oem(vend,pevt,outbuf,szbuf,fsensdesc,fdebug);
 	if (j == 0) return(0);  /*successful, have the description*/
 
 	if (psel->record_type == RT_OEMIU) { /* 0xDB usu ipmiutil OEM string */
-		   int ix = 0;
 		   /* ipmiutil OEM event with 9-byte string */
 		   pc = (uchar *)&psel->generator_id;  /* offset 7 */
 		   evtime = (uchar *)&psel->timestamp;
@@ -1615,9 +1619,9 @@ int decode_sel_entry( uchar *pevt, char *outbuf, int szbuf)
 		   		(evtime[2] << 16) + (evtime[3] << 24);
 		   fmt_time(eventTime, timebuf, sizeof(timebuf));
 		   if (fcanonical) 
-		     sprintf(outbuf,"%04x %c %s %c %s %c %02x %c %06x %c %s %c OEM Event ",
-                       psel->record_id, bdelim, timebuf, bdelim, 
-                       get_sev_str(sev), bdelim, psel->record_type, bdelim);
+		     sprintf(outbuf,"%04x %c %s %c %s %c %02x %c OEM Event ",
+			          psel->record_id, bdelim, timebuf, bdelim, 
+			          get_sev_str(sev), bdelim, psel->record_type, bdelim);
 		   else
 		     sprintf(outbuf,"%04x %s %s %02x OEM Event ", 
 			   psel->record_id, timebuf, get_sev_str(sev),
@@ -1632,8 +1636,6 @@ int decode_sel_entry( uchar *pevt, char *outbuf, int szbuf)
 		   outbuf[j++] = 0;
 	} else if (psel->record_type == 0xDC) {
 		   /* OEM Record: these are usually Microsoft */
-		   char *mfgstr;
-		   int mfg;
 		   evtime = (uchar *)&psel->timestamp;
 		   eventTime = evtime[0] + (evtime[1] << 8) + 
 		   		(evtime[2] << 16) + (evtime[3] << 24);
@@ -1658,8 +1660,6 @@ int decode_sel_entry( uchar *pevt, char *outbuf, int szbuf)
 		   outbuf[j++] = '\n';
 		   outbuf[j++] = 0;
 	} else if (psel->record_type == 0xDD) {  /* usu Intel OEM string */
-		   char *mfgstr;
-		   int mfg;
 		   int ix = 0;
 		   /* Windows reboot reason string from MS ipmidrv.sys */
 		   evtime = (uchar *)&psel->timestamp;
