@@ -165,7 +165,7 @@ void dbglog( char *pattn, ... ); /*local prototype*/
 /*
  * Global variables 
  */
-static char * progver   = "3.01";
+static char * progver   = "3.07";
 static char * progname  = "isol";
 static char  fdebug        = 0;
 static char  fpicmg        = 0;
@@ -1249,7 +1249,9 @@ main(int argc, char **argv)
 	case VENDOR_DELL:  /*Dell == 0x0002A2*/
 	   max_bmc_data = MAX_DELL_DATA; /*shorter max data*/
 	   break;
+	case VENDOR_SUPERMICROX:
 	case VENDOR_SUPERMICRO:
+   		if (!fprivset) parse_lan_options('V',"4",0); /*requires admin priv*/
 	case VENDOR_LMC:
 	case VENDOR_PEPPERCON: /* 0x0028C5  Peppercon/Raritan*/
            sol_timeout = 10;  /* shorter 10 sec SOL keepalive timeout */
