@@ -52,6 +52,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /* extern void get_mfgid(int *vend, int *prod);  * from ipmicmd.h*/
 /* extern int get_lan_options();  * from ipmicmd.h */
+static char * progver   = "3.07";
+static char * progname  = "ifujitsuoem";
 static char fdebug = 0;
 static char freadok = 1;
 #define ERRLED    0  /*GEL - red  Global Error LED*/
@@ -770,4 +772,11 @@ int decode_sensor_fujitsu(uchar *sdr,uchar *reading,char *pstring, int slen)
    return(rv);
 }
 
+#ifdef METACOMMAND
+int i_fujitsuoem(int argc, char **argv)
+{
+   printf("%s ver %s\n", progname,progver);
+   return(0);
+}
+#endif
 /* end oem_fujitsu.c */
