@@ -83,6 +83,8 @@ extern char  fdebug;   /*ipmicmd.c*/
 /*
  * Global variables 
  */
+static char * progver   = "3.07";
+static char * progname  = "iinteloem";
 static char  fRelayBits = 0;
 static uchar g_bus = PUBLIC_BUS;
 static uchar g_sa  = BMC_SA;
@@ -1893,4 +1895,11 @@ void show_enc_leds_intel(uchar val, int numd)
    else show_enc_leds_i2c(val, numd);
 }
 
+#ifdef METACOMMAND
+int i_inteloem(int argc, char **argv)
+{
+   printf("%s ver %s\n", progname,progver);
+   return(0);
+}
+#endif
 /* end oem_intel.c */
