@@ -73,6 +73,8 @@ typedef uint32_t   socklen_t;
 #define FRU_TYPE_COMPONENT  0x01
 #define FRU_TYPE_BASEBOARD  0x07
 
+static char * progver   = "3.07";
+static char * progname  = "ikontronoem";
 const struct valstr ktc5520_post[] = {  /*from EAS*/
  { 0x0003, "Start POST Init" },
  { 0x0004, "Check CMOS" },
@@ -943,19 +945,19 @@ int decode_sel_kontron(uint8_t *evt, char *outbuf, int outsz, char fdesc,
    if (rectype == 0xc1) {  /* OEM type C1 */
       oemid = evt[7] + (evt[8] << 8) + (evt[9] << 16);
       if (oemid == VENDOR_KONTRON) {
-         fmt_time(timestamp, timestr, sizeof(timestr));
-	 type_str = "Kontron";
-         gstr = "BMC ";
-	 switch(evt[10]) {
-	   case 0x01:
-	   default:
-		sprintf(mybuf,"OEM Event %02x %02x %02x %02x %02x %02x",
+		 fmt_time(timestamp, timestr, sizeof(timestr));
+		 type_str = "Kontron";
+		 gstr = "BMC ";
+		 switch(evt[10]) {
+		  case 0x01:
+		  default:
+		  sprintf(mybuf,"OEM Event %02x %02x %02x %02x %02x %02x",
 			evt[10], evt[11], evt[12], evt[13], evt[14], evt[15]);
-		break;
-	 }
-         snprintf(outbuf, outsz, "%04x %s %s %s %s %s\n",
+		  break;
+		 }
+		 snprintf(outbuf, outsz, "%04x %s %s %s %s %s\n",
                         id,timestr,get_sev_str(sevid), gstr, type_str, mybuf);
-	 rv = 0;
+		 rv = 0;
       } /*endif kontron*/
    } else if (rectype == 0x02) {
       type_str = "";
@@ -1103,4 +1105,11 @@ int decode_sensor_kontron(uchar *sdr,uchar *reading,char *pstring, int slen)
    return(rv);
 }
 
+#ifdef METACOMMAND
+int i_kontronoem(int argc, char **argv)
+{
+   printf("%s ver %s\n", progname,progver);
+   return(0);
+}
+#endif
 /* end oem_kontron.c */
