@@ -43,6 +43,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ipmicmd.h"
 #include "ievents.h"
 
+static char * progver   = "3.07";
+static char * progname  = "inewisysoem";
 static char  fdebug = 0;
 static uchar g_bus = PUBLIC_BUS;
 static uchar g_sa  = BMC_SA;
@@ -126,4 +128,11 @@ int decode_sel_newisys(uchar *evt, char *outbuf, int outsz, char fdesc,
    return rv;
 }
 
+#ifdef METACOMMAND
+int i_newisysoem(int argc, char **argv)
+{
+   printf("%s ver %s\n", progname,progver);
+   return(0);
+}
+#endif
 /* end oem_newisys.c */
